@@ -11,6 +11,7 @@
 
 from argparse import ArgumentParser
 from pybedtools import BedTool
+import gzip
 
 
 
@@ -18,15 +19,39 @@ from pybedtools import BedTool
 # Functions ====================================================================
 
 def parse_gff_attributes(attr):
+    """Parse an entry from the "attr" column of a GFF3 file and yield it as
+    a dict
+
+    Parameters
+    ----------
+    attr : str
+        feature attribute string
+
+    Returns
+    ------
+    dict
+        attr entries as a dict
+    """
+
     return dict(pair.split('=') for pair in attr.split(';'))
 
 
 def parse_gff(gff: str, type='gene'):
-    with open(gff) as f:
+    """Parse a GFF3 file and yield its lines as tuples
+
+    Parameters
+    ----------
+    gff : str
+        path to GFF3 file
+    type
+        string indcicating feature type to include, or None to include all
+        features
+    """
+
+    with (gzip.open(gff, 'rt') if gff.endswith('.gz') else open(gff)) as f:
         for l in f:
              if not l.startswith('#'):
-                seqid, _, t, start, end, _, strand, _, attr = l.rstrip().split(
-                                                                           '\t')
+                seqid, _, t, start, end, _, strand, _, attr = l.rstrip().split('\t')
                 if ((t == type) or (type is None)):
                     yield (seqid, int(start), int(end), strand,
                            parse_gff_attributes(attr))
