@@ -2,7 +2,9 @@
 # gtracks.py
 #===============================================================================
 
-"""Plot bigWig signal tracks and gene annotations in a genomic region"""
+"""Plot bigWig, BEDgraph, or BED signal tracks and gene annotations in a
+genomic region
+"""
 
 
 
@@ -35,6 +37,16 @@ max_value = {max}
 file_type = bigwig
 """
 
+BEDGRAPH_CONFIG_FORMAT = """
+[{title}]
+file = {file}
+title = {title}
+height = 2
+color = {color}
+min_value = 0
+max_value = {max}
+file_type = bedgraph
+"""
 
 BED4_CONFIG_FORMAT = """
 [{title}]
@@ -119,7 +131,10 @@ def make_tracks_file(
             BIGWIG_CONFIG_FORMAT.format(
                 file=track, title=os.path.basename(track).split('.')[0],
                 color=color, max=m
-            ) if track.endswith('.bw') else SPACER + BED4_CONFIG_FORMAT.format(
+            ) if track.endswith('.bw') else BEDGRAPH_CONFIG_FORMAT.format(
+                file=track, title=os.path.basename(track).split('.')[0],
+                color=color, max=m
+            ) if track.endswith('.bdg') else SPACER + BED4_CONFIG_FORMAT.format(
                 file=track, title=os.path.basename(track).split('.')[0],
                 color=color, labels='true' if bed_labels else 'false'
             ) if track.endswith('.bed') else ''
@@ -260,9 +275,9 @@ def parse_arguments():
     )
     args = parser.parse_args()
     for t in args.track:
-        if not (t.endswith('.bw') or t.endswith('.bed')):
+        if not any((t.endswith(ext) for ext in ('.bw', '.bdg', '.bed'))):
             raise RuntimeError(
-                'track file extensions must be either .bw or .bed')
+                'track file extensions must be one of .bw, .bdg, or .bed')
     if args.genes in set(GENOME_TO_GENES.keys()):
         genes_path = GENOME_TO_GENES[args.genes]
         args.genes = genes_path
